==> open-xchange-mobile-api-facade_1.2.0.orig.tar.bz2: open-xchange-mobile-api-facade-1.2.0/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/configuration/GlobalConfiguration.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.configuration;

import java.net.URI;
import java.net.URISyntaxException;

import com.openexchange.config.ConfigurationService;
import com.openexchange.java.Strings;

import lombok.experimental.UtilityClass;
import lombok.extern.slf4j.Slf4j;

@Slf4j
@UtilityClass
public class GlobalConfiguration {

    public static final String MIDDLEWARE_BASE_URL = "com.openexchange.mobile.api.facade.MiddlewareBaseUrl";

    public static URI middlewareBaseUrl;

    static {
        try {
            middlewareBaseUrl = new URI("http://localhost:8009/ajax/");
        } catch (URISyntaxException e) {
            e.printStackTrace();
        }
    }

    public void initialize(ConfigurationService configurationService) {
        middlewareBaseUrl = getMiddlewareBaseUrl(configurationService);
        validate();
    }

    private void validate() {
        if (middlewareBaseUrl == null) {
            log.error("property \"" + MIDDLEWARE_BASE_URL + "\" not set");
        } else if (Strings.isEmpty(middlewareBaseUrl.getHost())) {
            log.error("hostname cannot get extracted from property \"" + MIDDLEWARE_BASE_URL + "\"");
        }
    }

    private URI getMiddlewareBaseUrl(ConfigurationService configurationService) {
        try {
            String value = ConfigurationHelper.getStringOrNull(configurationService, MIDDLEWARE_BASE_URL);
            if (Strings.isEmpty(value)) {
                return null;
            }
            if (!value.endsWith("/")) {
                value += "/";
            }
            return new URI(value);
        } catch (Exception e) {
            return null;
        }
    }

}

==> open-xchange-mobile-api-facade_1.8.5.orig.tar.bz2: open-xchange-mobile-api-facade-1.8.5/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/configuration/GlobalConfiguration.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.configuration;

import java.net.URI;
import java.net.URISyntaxException;

import com.openexchange.config.ConfigurationService;
import com.openexchange.java.Strings;

import lombok.experimental.UtilityClass;
import lombok.extern.slf4j.Slf4j;

@Slf4j
@UtilityClass
public class GlobalConfiguration {

    public static final String MIDDLEWARE_BASE_URL = "com.openexchange.mobile.api.facade.MiddlewareBaseUrl";

    public static final String VERSION_CHECK_ENABLED = "com.openexchange.mobile.api.facade.versionCheckEnabled";

    public static URI middlewareBaseUrl;

    public static boolean versionCheckEnabled;

    static {
        try {
            middlewareBaseUrl = new URI("http://localhost:8009/ajax/");
        } catch (URISyntaxException e) {
            e.printStackTrace();
        }
    }

    public void initialize(ConfigurationService configurationService) {
        middlewareBaseUrl = getMiddlewareBaseUrl(configurationService);
        versionCheckEnabled = ConfigurationHelper.getBoolean(configurationService, VERSION_CHECK_ENABLED, true);
        validate();
    }

    private void validate() {
        if (middlewareBaseUrl == null) {
            log.error("property \"" + MIDDLEWARE_BASE_URL + "\" not set");
        } else if (Strings.isEmpty(middlewareBaseUrl.getHost())) {
            log.error("hostname cannot get extracted from property \"" + MIDDLEWARE_BASE_URL + "\"");
        }
    }

    private URI getMiddlewareBaseUrl(ConfigurationService configurationService) {
        try {
            String value = ConfigurationHelper.getStringOrNull(configurationService, MIDDLEWARE_BASE_URL);
            if (Strings.isEmpty(value)) {
                return null;
            }
            if (!value.endsWith("/")) {
                value += "/";
            }
            return new URI(value);
        } catch (Exception e) {
            return null;
        }
    }

}
